local f = InfoPanel.AddPlugin();

local pName = UnitName("player");
local combStart, combTime, dmgTotal;
local prefix, suffix;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnEnter
local function OnEnter(self)
	InfoPanel.MakeTip(f,"DPS Info");
	if (dmgTotal) then
		GameTooltip:AddDoubleLine("Total Damage",dmgTotal,nil,nil,nil,1,1,1);
		GameTooltip:AddDoubleLine("Combat Time",InfoPanel.FormatTime2(combTime),nil,nil,nil,1,1,1);
	end
	GameTooltip:Show();
end

-- Show DPS
local function UpdateDPS()
	if (combTime == 0) then
		InfoPanel.SetText(f,"0");
	else
		InfoPanel.SetText(f,format("%.1f",dmgTotal / combTime));
	end
end

-- OnEvent
local function OnEvent(self,event,time,type,sourceGUID,sourceName,sourceFlags,destGUID,destName,destFlags,...)
	-- combat status
	if (event == "PLAYER_REGEN_ENABLED") then
		f:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
		combTime = (GetTime() - combStart);
		UpdateDPS();
	elseif (event == "PLAYER_REGEN_DISABLED") then
		dmgTotal = 0;
		combStart = GetTime();
		combTime = 0;
		f:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
	-- combat log
	elseif (sourceName == pName) and (destName ~= pName) then
		prefix, suffix = type:match("(.-)_(.+)");
		if (suffix == "DAMAGE" or suffix == "PERIODIC_DAMAGE" or suffix == "SHIELD") then
--			AzMsg(type.." = "..select(prefix == "SWING" and 1 or 4,...));
			dmgTotal = (dmgTotal + select(prefix == "SWING" and 1 or 4,...));
			combTime = (GetTime() - combStart);
			UpdateDPS();
		end
	end
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

f.icon:SetTexture("Interface\\Icons\\Ability_Warrior_Rampage");
f:SetScript("OnEnter",OnEnter);
f:SetScript("OnEvent",OnEvent);
f:RegisterEvent("PLAYER_REGEN_ENABLED");
f:RegisterEvent("PLAYER_REGEN_DISABLED");
InfoPanel.SetText(f,"0");