local f = InfoPanel.AddPlugin();
local sessionHonor, honorThisZone, honorPrevZone;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnEnter
local function OnEnter(self)
	InfoPanel.MakeTip(f,"Honor Details");

	local kills, points = GetPVPSessionStats();
	-- Session/Zone Honor
	GameTooltip:AddDoubleLine("This Session's Honor",GetHonorCurrency() - sessionHonor,nil,nil,nil,1,1,1);
	if (honorThisZone) then
		GameTooltip:AddDoubleLine("This Zone's Honor",points - honorThisZone,nil,nil,nil,1,1,1);
		if (honorPrevZone) then
			GameTooltip:AddDoubleLine("Last Zone's Honor",honorThisZone - honorPrevZone,nil,nil,nil,1,1,1);
		end
		GameTooltip:AddLine(" ");
	end
	-- Today's values
	GameTooltip:AddDoubleLine("Today's Kills",kills,nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("Today's Points",points,nil,nil,nil,1,1,1);
	GameTooltip:AddLine(" ");
	-- Yesterday's values
	kills, points = GetPVPYesterdayStats();
	GameTooltip:AddDoubleLine("Yesterday's Kills",kills,nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("Yesterday's Points",points,nil,nil,nil,1,1,1);
	GameTooltip:AddLine(" ");
	-- Lifetime stats
	local highestRank;
	kills, highestRank = GetPVPLifetimeStats();
	GameTooltip:AddDoubleLine("Lifetime Kills",kills,nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("Highest Rank",highestRank,nil,nil,nil,1,1,1);
	GameTooltip:AddLine(" ");
	-- Rank
	local rankName, rankNumber = GetPVPRankInfo(highestRank);
	if ( not rankName ) then
		rankName = NONE;
	end
	GameTooltip:AddDoubleLine("Rank Name",rankName,nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("Rank Number",rankNumber,nil,nil,nil,1,1,1);
	GameTooltip:AddLine(" ");
	-- Points
	GameTooltip:AddDoubleLine("Honor Points",GetHonorCurrency(),nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("Arena Points",GetArenaCurrency(),nil,nil,nil,1,1,1);
	-- PvP Time
	local pvpTime = GetPVPTimer();
	if (pvpTime) and (pvpTime < 301000) then
		GameTooltip:AddLine(" ");
		GameTooltip:AddDoubleLine("PvP Flag Time",InfoPanel.FormatTime(pvpTime / 1000),nil,nil,nil,1,1,1);
	end;

	GameTooltip:Show();
end

-- OnEvent
local function OnEvent(self,event,...)
	if (event == "PLAYER_ENTERING_WORLD") or (event == "ZONE_CHANGED_NEW_AREA") then
		honorPrevZone = honorThisZone;
		honorThisZone = select(2,GetPVPSessionStats());
	else
		if (event == "PLAYER_LOGIN") then
			sessionHonor = GetHonorCurrency();
		end
		--InfoPanel.SetText(f,select(2,GetPVPSessionStats()));
		InfoPanel.SetText(f,GetHonorCurrency());
	end
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

f.icon:SetTexture("Interface\\TargetingFrame\\UI-PVP-"..UnitFactionGroup("player"));
--f.icon:SetTexCoord(0,0.55,0,0.55);
f.icon:SetTexCoord(0,0.62,0,0.62);
f:SetScript("OnEnter",OnEnter);
f:SetScript("OnEvent",OnEvent);
f:RegisterEvent("PLAYER_LOGIN");
f:RegisterEvent("HONOR_CURRENCY_UPDATE");
--f:RegisterEvent("PLAYER_ENTERING_WORLD");
f:RegisterEvent("ZONE_CHANGED_NEW_AREA");