local _G = getfenv(0);
local f = InfoPanel.AddPlugin();
local sessionRep = {};

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnEnter
local function OnEnter(self)
	InfoPanel.MakeTip(f,"Reputation Info");
	-- Scan Factions
	local _, factionName, standing, minValue, maxValue, earnedValue, isHeader;
	local factionStandings = {};
	local factionCount = 0;
	local repChange, color;
	-- Loop
	for i = 1, GetNumFactions() do
		factionName, _, standing, minValue, maxValue, earnedValue, _, _, isHeader = GetFactionInfo(i);
		if (not isHeader) then
			factionStandings[standing] = (factionStandings[standing] or 0) + 1;
			factionCount = (factionCount + 1);
		end
		if (IsShiftKeyDown()) then
			color = FACTION_BAR_COLORS[standing];
			GameTooltip:AddDoubleLine((isHeader and "|cffffffff- " or "")..factionName,_G["FACTION_STANDING_LABEL"..standing].." - "..(earnedValue - minValue).."/"..(maxValue - minValue),nil,nil,nil,color.r,color.g,color.b);
		elseif (sessionRep[factionName]) then
			repChange = (earnedValue - sessionRep[factionName]);
			if (repChange ~= 0) then
				repChange = ((repChange > 0 and "|cff80ff80+") or (repChange < 0 and "|cffff8080-") or "")..abs(repChange);
				GameTooltip:AddDoubleLine((isHeader and "|cffffffff- " or "")..factionName,repChange,nil,nil,nil,1,1,1);
			end
		end
	end
	-- Add Faction Standings
	if (not IsShiftKeyDown()) then
		if (GameTooltip:NumLines() > 1) then
			GameTooltip:AddLine(" ");
			GameTooltip:AddLine("Standings",1,1,1);
		end;
		GameTooltip:AddDoubleLine("Known Factions",factionCount,nil,nil,nil,1,1,1);
		for standing, factionCount in pairs(factionStandings) do
			color = FACTION_BAR_COLORS[standing]
			GameTooltip:AddDoubleLine(_G["FACTION_STANDING_LABEL"..standing],factionCount,nil,nil,nil,color.r,color.g,color.b);
		end
		-- watched Faction
		local name, standing, min, max, value = GetWatchedFactionInfo();
		if (name) then
			GameTooltip:AddLine(" ");
			GameTooltip:AddDoubleLine("Watched Faction",name,nil,nil,nil,1,1,1);
		end
	end
	-- Fin
	GameTooltip:Show();
end

-- Gather Info
local function OnEvent(self,event)
	-- Check faction count
	local nFactions = GetNumFactions();
	if (nFactions == 0) then
		return;
	end
	-- Set initial Rep for factions not yet saved
	local _, factionName, earnedValue;
	for i = 1, nFactions do
		factionName, _, _, _, _, earnedValue = GetFactionInfo(i);
		if (not sessionRep[factionName]) then
			sessionRep[factionName] = earnedValue;
		end
	end
	-- Update Rep
	local name, standing, min, max, value = GetWatchedFactionInfo();
	if (name) then
		local color = FACTION_BAR_COLORS[standing];
		InfoPanel.SetText(f,_G["FACTION_STANDING_LABEL"..standing].." - "..(value - min).."/"..(max - min));
		f.text:SetTextColor(color.r,color.g,color.b);
	else
		InfoPanel.SetText(f,"Rep");
		f.text:SetTextColor(1,1,1);
	end;
end

-- OnClick
local function OnClick(self,button)
	if (ChatFrameEditBox:IsShown()) then
		local name, standing, min, max, value = GetWatchedFactionInfo();
		if (name) then
			ChatFrameEditBox:Insert(format("%s: %d / %d",name,value - min,max - min));
		else
			ChatFrameEditBox:Insert("n/a");
		end
	end
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

f.icon:SetTexture("Interface\\Icons\\Achievement_Reputation_01");
f:SetScript("OnEnter",OnEnter);
f:SetScript("OnEvent",OnEvent);
f:SetScript("OnClick",OnClick);
f:RegisterEvent("UPDATE_FACTION");
-- Change exalted color to make them stand out
FACTION_BAR_COLORS[8] = {r = 0.2, g = 0.6, b = 1};