if (UnitLevel("player") == MAX_PLAYER_LEVEL) then
	return;
end

local f = InfoPanel.AddPlugin();
local sessionStart = GetTime();
local xpNow, xpMax;
local xpLast, xpLastMax = 0;
local xpSession, xpCombat, xpGain = 0, 0;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnEnter
local function OnEnter(self)
	InfoPanel.MakeTip(f,"Experience Info");

	GameTooltip:AddDoubleLine("Current XP",xpNow,nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("Maximum XP",xpMax,nil,nil,nil,1,1,1);
	GameTooltip:AddDoubleLine("XP to Next Level",xpMax - xpNow,nil,nil,nil,1,1,1);
	local xpRest = GetXPExhaustion();
	if (xpRest) then
		GameTooltip:AddDoubleLine("Rested XP",xpRest,nil,nil,nil,0,1,0);
	end

	if (xpGain) then
		GameTooltip:AddLine(" ");
		GameTooltip:AddDoubleLine("Last XP Gain",xpGain,nil,nil,nil,1,1,1);
		GameTooltip:AddDoubleLine("Equal Gains to Level",format("%.2f",(xpMax - xpNow) / xpGain),nil,nil,nil,1,1,1);
		GameTooltip:AddDoubleLine("Gain Percentage",format("%.2f%%",xpGain / xpMax * 100),nil,nil,nil,1,1,1);
		GameTooltip:AddLine(" ");
		GameTooltip:AddDoubleLine("Last Combat XP Gain",xpCombat,nil,nil,nil,1,1,1);
		GameTooltip:AddDoubleLine("Gain Percentage",format("%.2f%%",xpCombat / xpMax * 100),nil,nil,nil,1,1,1);
	end

	if (xpSession > 0) then
		local xpPerHour = (xpSession / ((GetTime() - sessionStart) / 3600)); 
		GameTooltip:AddLine(" ");
		GameTooltip:AddDoubleLine("XP Gain This Session",xpSession,nil,nil,nil,1,1,1);
		GameTooltip:AddDoubleLine("XP Gain Per Hour",format("%.1f",xpPerHour),nil,nil,nil,1,1,1);
		GameTooltip:AddDoubleLine("Time to Next Level",InfoPanel.FormatTime3((xpMax - xpNow) / xpPerHour * 3600),nil,nil,nil,1,1,1);
	end

	GameTooltip:Show();
end

-- Splash Message
local function SplashMsg(header,subtext,r,g,b)
	ZoneTextString:SetText(header);
	ZoneTextString:SetTextColor(r,g,b);
	ZoneTextFrame.startTime = GetTime();
	SubZoneTextString:SetText(subtext);
	SubZoneTextString:SetTextColor(r,g,b);
	SubZoneTextFrame.startTime = GetTime();
	PVPInfoTextString:SetText(""); -- Clear this so it wont show: Alliance/Horde/Contested territory.
	ZoneTextFrame:Show();
	SubZoneTextFrame:Show();
end

-- Gather Info
local function OnEvent(self,event,...)
	if (event == "PLAYER_XP_UPDATE" or event == "PLAYER_LOGIN") then
		xpNow, xpMax = UnitXP("player"), UnitXPMax("player");
		if (event == "PLAYER_XP_UPDATE") and (xpNow ~= xpLast) then
			xpGain = (xpNow > xpLast) and (xpNow - xpLast) or (xpNow + xpLastMax - xpLast);
			xpSession = (xpSession + xpGain);
			xpCombat = (xpCombat + xpGain);
		end
		xpLast, xpLastMax = xpNow, xpMax;
		InfoPanel.SetText(f,"%.2f%%",xpNow / xpMax * 100);
	elseif (event == "PLAYER_REGEN_DISABLED") then
		xpCombat = 0;
	elseif (event == "PLAYER_LEVEL_UP") then
		SplashMsg("Level "..select(1,...),"Congratulations!",127/255,192/255,255/255);
	end
end

-- OnClick
local function OnClick(self,button)
	if (ChatFrameEditBox:IsShown()) then
		ChatFrameEditBox:Insert(format("%d / %d (%.2f%%)",xpNow,xpMax,xpNow / xpMax * 100));
	elseif (IsShiftKeyDown()) and (button == "RightButton") then
		sessionStart = GetTime();
		xpLast, xpLastMax = 0, nil;		
		xpSession, xpCombat, xpGain = 0, 0, nil;
		OnEvent(f,"PLAYER_LOGIN");
		AzMsg("|2InfoPanel|r: Experience Info has been reset");
	end
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

f.icon:SetTexture("Interface\\Icons\\Spell_Fire_FelFlameRing");
f:SetScript("OnEnter",OnEnter);
f:SetScript("OnEvent",OnEvent);
f:SetScript("OnClick",OnClick);
f:RegisterEvent("PLAYER_LOGIN");
f:RegisterEvent("PLAYER_XP_UPDATE");
f:RegisterEvent("PLAYER_LEVEL_UP");
f:RegisterEvent("PLAYER_REGEN_DISABLED");